@@ -12,7 +12,7 @@ from .model import Py2NDeviceData, Py2NDeviceSwitch, Py2NConnectionData
 
 from .exceptions import NotInitialized, Py2NError
 
-from .utils import get_info, get_status, restart, get_switches, set_switch
+from .utils import get_info, get_status, restart, test_audio, get_switches, set_switch
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -85,12 +85,35 @@ class Py2NDevice:
             self._last_error = err
             raise
     
+    async def audio_test(self) -> None:
+        try:
+            await test_audio(self.aiohttp_session, self.options)
+        except Py2NError as err:
+            self._last_error = err
+            raise
+    
     async def set_switch(self, switch_id, on) -> None:
+        if not self._data.switches:
+            raise Py2NError("no switches configured")
+
+        if switch_id < 1 | switch_id > len(self._data.switches):
+            raise Py2NError("invalid switch id")
+
         try:
             await set_switch(self.aiohttp_session, self.options, switch_id, on)
         except Py2NError as err:
             self._last_error = err
             raise
+    
+    def get_switch(self, switch_id) -> bool:
+        if not self._data.switches:
+            raise Py2NError("no switches configured")
+        
+        if switch_id < 1 | switch_id > len(self._data.switches):
+            raise Py2NError("invalid switch id")
+
+        retur
+
 
     @property
     def ip_address(self) -> str:
